<?php
require_once "connect.php"; // فایل اتصال به دیتابیس

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $code = trim($_POST['code']);
    $discount_percent = intval($_POST['discount_percent']);
    $expires_at = $_POST['expires_at'];
    $is_active = isset($_POST['is_active']) ? 1 : 0;

    if (empty($code) || empty($discount_percent) || empty($expires_at)) {
        $message = "لطفاً تمام فیلدها را پر کنید!";
    } else {
        try {

            $stmt = $conn->prepare("INSERT INTO discount_code (code, discount_percent, is_active, expires_at) VALUES (:code, :discount_percent, :is_active, :expires_at)");
            $stmt->bindParam(':code', $code);
            $stmt->bindParam(':discount_percent', $discount_percent);
            $stmt->bindParam(':is_active', $is_active);
            $stmt->bindParam(':expires_at', $expires_at);

            if ($stmt->execute()) {
                $message = "کد تخفیف با موفقیت افزوده شد!";
                $success = true;
            } else {
                $message = "خطایی رخ داد، لطفاً دوباره امتحان کنید!";
            }
        } catch (PDOException $e) {
            $message = "خطای پایگاه داده: " . $e->getMessage();
        }
    }
}
?>

<!DOCTYPE html>
<html lang="fa">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>افزودن کد تخفیف</title>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
</head>
<body class="bg-light">

<div class="container mt-5">
    <div class="card shadow p-4">
        <h3 class="text-center mb-4">افزودن کد تخفیف</h3>

        <?php if (isset($message)): ?>
            <div class="alert <?php echo isset($success) ? 'alert-success' : 'alert-danger'; ?>">
                <?php echo $message; ?>
            </div>
        <?php endif; ?>

        <form method="POST">
            <div class="mb-3">
                <label class="form-label">کد تخفیف</label>
                <input type="text" name="code" class="form-control" required>
            </div>

            <div class="mb-3">
                <label class="form-label">درصد تخفیف</label>
                <input type="number" name="discount_percent" class="form-control" required min="1" max="100">
            </div>

            <div class="mb-3">
                <label class="form-label">تاریخ انقضا</label>
                <input type="datetime-local" name="expires_at" class="form-control" required>
            </div>

            <div class="mb-3 form-check">
                <input type="checkbox" name="is_active" class="form-check-input" checked>
                <label class="form-check-label">فعال باشد</label>
            </div>

            <button type="submit" class="btn btn-primary w-100">افزودن</button>
        </form>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
