<?php
require_once 'connect.php'; // اتصال به دیتابیس

// دریافت اطلاعات محصول
if (isset($_GET['id'])) {
    $product_id = $_GET['id'];
    $query = "SELECT * FROM tbl_product WHERE id = :id";
    $stmt = $conn->prepare($query);
    $stmt->bindParam(':id', $product_id, PDO::PARAM_INT);
    $stmt->execute();
    $product = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$product) {
        echo "<script>alert('محصول یافت نشد!'); window.location.href = 'manage_offer.php';</script>";
        exit();
    }
}

// به‌روزرسانی اطلاعات محصول
if (isset($_POST['update'])) {
    $discount = $_POST['discount'];
    $date_discount = $_POST['date_discount'];

    $update_query = "UPDATE tbl_product SET discount = :discount, date_discount = :date_discount WHERE id = :id";
    $update_stmt = $conn->prepare($update_query);
    $update_stmt->bindParam(':discount', $discount, PDO::PARAM_INT);
    $update_stmt->bindParam(':date_discount', $date_discount, PDO::PARAM_STR);
    $update_stmt->bindParam(':id', $product_id, PDO::PARAM_INT);
    $update_stmt->execute();
    
    $update_cart_query = "UPDATE tbl_basket SET discount = :discount, date_discount = :date_discount WHERE idproduct = :id";
    $update_cart_stmt = $conn->prepare($update_cart_query);
    $update_cart_stmt->bindParam(':discount', $discount, PDO::PARAM_INT);
    $update_cart_stmt->bindParam(':date_discount', $date_discount, PDO::PARAM_STR);
    $update_cart_stmt->bindParam(':id', $product_id, PDO::PARAM_INT);
    $update_cart_stmt->execute();

    echo "<script>alert('اطلاعات تخفیف به‌روزرسانی شد.'); window.location.href = 'manage_offer.php';</script>";
}
?>

<!DOCTYPE html>
<html lang="fa" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>ویرایش تخفیف محصول</title>

    <!-- لینک‌های Bootstrap -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.rtl.min.css" rel="stylesheet">
    
    <!-- فونت فارسی وزیرمتن -->
    <link href="https://cdn.jsdelivr.net/gh/rastikerdar/vazirmatn@latest/dist/font-face.css" rel="stylesheet">
    
    <style>
        body {
            font-family: 'Vazirmatn', sans-serif;
            background-color: #f8f9fa;
        }
        .container {
            max-width: 600px;
            margin: 50px auto;
            background: white;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0px 4px 10px rgba(0, 0, 0, 0.1);
        }
        h2 {
            text-align: center;
            color: #007bff;
            margin-bottom: 20px;
        }
        label {
            font-weight: bold;
        }
        .btn-save {
            background-color: #28a745;
            color: white;
        }
        .btn-save:hover {
            background-color: #218838;
        }
    </style>
</head>
<body>

<div class="container">
    <h2>ویرایش تخفیف محصول</h2>
    <form method="post">
        <div class="mb-3">
            <label for="name" class="form-label">نام محصول:</label>
            <input type="text" id="name" class="form-control" value="<?= htmlspecialchars($product['name']) ?>" disabled>
        </div>

        <div class="mb-3">
            <label for="price" class="form-label">قیمت (تومان):</label>
            <input type="text" id="price" class="form-control" value="<?= number_format($product['price']) ?>" disabled>
        </div>

        <div class="mb-3">
            <label for="discount" class="form-label">درصد تخفیف:</label>
            <input type="number" id="discount" name="discount" class="form-control" value="<?= htmlspecialchars($product['discount']) ?>" min="0" max="100" required>
        </div>

        <div class="mb-3">
            <label for="date_discount" class="form-label">تاریخ پایان تخفیف:</label>
            <input type="date" id="date_discount" name="date_discount" class="form-control" value="<?= htmlspecialchars($product['date_discount']) ?>" required>
        </div>

        <div class="d-grid">
            <button type="submit" name="update" class="btn btn-save">ذخیره تغییرات</button>
        </div>
    </form>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

</body>
</html>
