<?php
include "connect.php";

try {
    // گرفتن لیست سفارش‌ها با JOIN کردن با جدول users
    $stmt = $conn->prepare("
        SELECT tbl_pyment.*, users.first_name AS username
        FROM tbl_pyment
        JOIN users ON tbl_pyment.userid = users.id
    ");
    $stmt->execute();

    // نمایش هر سفارش در جدول
    if ($stmt->rowCount() > 0) {
        echo "
        <!DOCTYPE html>
        <html lang='fa'>
        <head>
            <meta charset='UTF-8'>
            <meta name='viewport' content='width=device-width, initial-scale=1.0'>
            <title>مدیریت سفارش‌ها</title>
            <link href='https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css' rel='stylesheet'>
            <style>
                body {
                    font-family: Tahoma, sans-serif;
                    background-color: #f4f6f9;
                    direction: rtl; /* راستچین کردن صفحه */
                }
                .container {
                    margin-top: 50px;
                }
                .table th, .table td {
                    text-align: right; /* راستچین کردن سلول‌ها */
                    vertical-align: middle;
                }
                .btn-sm {
                    padding: 5px 10px;
                }
                h2 {
                    margin-bottom: 30px;
                    text-align: center;
                }
            </style>
        </head>
        <body>
            <div class='container'>
                <h2>مدیریت سفارش‌ها</h2>
                <table class='table table-bordered table-striped'>
                    <thead class='thead-dark'>
                        <tr>
                            <th>ID</th>
                            <th>نام مشتری</th>
                            <th>مبلغ سفارش</th>
                            <th>تاریخ و زمان</th>
                            <th>وضعیت</th>
                            <th>عملیات</th>
                        </tr>
                    </thead>
                    <tbody>";

        // نمایش نتایج
        while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
            // تبدیل وضعیت به فارسی
            $status_fa = '';
            switch ($row["status"]) {
                case 'pending':
                    $status_fa = 'در حال بررسی';
                    break;
                case 'paid':
                    $status_fa = 'در حال بسته بندی';
                    break;
                case 'done':
                    $status_fa = 'تحویل داده شده';
                    break;
                default:
                    $status_fa = 'نامشخص';
                    break;
            }

            echo "<tr>
                    <td>" . $row["id"]. "</td>
                    <td>" . $row["username"]. "</td>
                    <td>" . number_format($row["amount"]/10) . " تومان</td>
                    <td>" . $row["create_at"] . ",".$row["time_at"]."</td>
                    <td id='status_" . $row["id"] . "'>" . $status_fa . "</td>
                    <td>
                        <button class='btn btn-warning btn-sm' onclick='changeStatus(" . $row["id"] . ", \"pending\")'>در حال بررسی</button>
                        <button class='btn btn-primary btn-sm' onclick='changeStatus(" . $row["id"] . ", \"paid\")'>در حال بسته بندی</button>
                        <button class='btn btn-success btn-sm' onclick='changeStatus(" . $row["id"] . ", \"done\")'>تحویل داده شده</button>
                    </td>
                  </tr>";
        }

        echo "</tbody></table>
            </div>

            <script src='https://code.jquery.com/jquery-3.6.0.min.js'></script>
            <script src='https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js'></script>
            <script>
                function changeStatus(orderId, newStatus) {
                    $.ajax({
                        url: 'update_status.php',
                        type: 'GET',
                        data: {
                            id: orderId,
                            status: newStatus
                        },
                        success: function(response) {
                            // بروزرسانی وضعیت در جدول بدون بارگذاری مجدد صفحه
                            let statusText = '';
                            switch(newStatus) {
                                case 'pending':
                                    statusText = 'در حال بررسی';
                                    break;
                                case 'paid':
                                    statusText = 'در حال بسته بندی';
                                    break;
                                case 'done':
                                    statusText = 'تحویل داده شده';
                                    break;
                            }
                            $('#status_' + orderId).text(statusText);
                            alert('وضعیت سفارش با موفقیت تغییر یافت!');
                        },
                        error: function() {
                            alert('خطا در تغییر وضعیت!');
                        }
                    });
                }
            </script>
        </body>
        </html>";
    } else {
        echo "<div class='container mt-5'><p class='text-center'>هیچ سفارشی یافت نشد.</p></div>";
    }
}
catch(PDOException $e) {
    echo "اتصال به پایگاه داده موفقیت‌آمیز نبود: " . $e->getMessage();
}

$conn = null;
?>
