<?php
require_once 'connect.php'; // فایل اتصال به دیتابیس

// دریافت محصولات شگفت‌انگیز
$query = "SELECT * FROM tbl_product WHERE hasDiscount = 'yes'";
$stmt = $conn->prepare($query);
$stmt->execute();
$products = $stmt->fetchAll(PDO::FETCH_ASSOC);

if (isset($_POST['delete'])) {
    $product_id = $_POST['product_id'];
    
    // حذف تخفیف از محصول اصلی
    $update_product = $conn->prepare("UPDATE tbl_product SET hasDiscount = 'no', discount = 0, date_discount = NULL WHERE id = :id");
    $update_product->bindParam(':id', $product_id, PDO::PARAM_INT);
    $update_product->execute();
    
    // حذف تخفیف از سبد خرید در صورت وجود
    $update_cart = $conn->prepare("UPDATE tbl_basket SET hasDiscount = 'no', discount = 0, date_discount = NULL WHERE idproduct = :id");
    $update_cart->bindParam(':id', $product_id, PDO::PARAM_INT);
    $update_cart->execute();
    
    echo "<script>alert('تخفیف محصول حذف شد.'); window.location.href = 'manage_offer.php';</script>";
}
?>

<!DOCTYPE html>
<html lang="fa" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>مدیریت تخفیفات</title>
    
    <!-- لینک‌های Bootstrap -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.rtl.min.css" rel="stylesheet">
    
    <!-- لینک فونت فارسی زیبا -->
    <link href="https://cdn.jsdelivr.net/gh/rastikerdar/vazirmatn@latest/dist/font-face.css" rel="stylesheet">
    
    <style>
        body {
            font-family: 'Vazirmatn', sans-serif;
            background-color: #f8f9fa;
        }
        .container {
            max-width: 900px;
            margin: 40px auto;
            background: white;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0px 4px 10px rgba(0, 0, 0, 0.1);
        }
        h2 {
            color: #007bff;
            text-align: center;
            margin-bottom: 20px;
        }
        table {
            width: 100%;
            border-collapse: collapse;
        }
        th, td {
            padding: 12px;
            text-align: center;
        }
        th {
            background-color: #007bff;
            color: white;
        }
        tbody tr:nth-child(odd) {
            background-color: #f2f2f2;
        }
        .btn-edit {
            background-color: #28a745;
            color: white;
            border-radius: 5px;
            padding: 5px 10px;
            text-decoration: none;
        }
        .btn-edit:hover {
            background-color: #218838;
        }
        .btn-delete {
            background-color: #dc3545;
            color: white;
            border-radius: 5px;
            padding: 5px 10px;
            border: none;
            cursor: pointer;
        }
        .btn-delete:hover {
            background-color: #c82333;
        }
    </style>
</head>
<body>

<div class="container">
    <h2>مدیریت محصولات شگفت‌انگیز</h2>

    <table class="table table-bordered">
        <thead>
            <tr>
                <th>نام محصول</th>
                <th>قیمت (تومان)</th>
                <th>درصد تخفیف</th>
                <th>تاریخ پایان تخفیف</th>
                <th>عملیات</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($products as $product): ?>
                <tr>
                    <td><?= htmlspecialchars($product['name']) ?></td>
                    <td><?= number_format($product['price']) ?></td>
                    <td><?= htmlspecialchars($product['discount']) ?>%</td>
                    <td><?= htmlspecialchars($product['date_discount']) ?></td>
                    <td>
                        <a href="edit_offer.php?id=<?= $product['id'] ?>" class="btn-edit">ویرایش</a>
                        <form method="post" style="display:inline;">
                            <input type="hidden" name="product_id" value="<?= $product['id'] ?>">
                            <button type="submit" name="delete" class="btn-delete" onclick="return confirm('آیا مطمئن هستید؟')">حذف</button>
                        </form>
                    </td>
                </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

</body>
</html>
