<?php
include "connect.php";

// تعداد محصولات در هر صفحه
$products_per_page = 5;

// دریافت عبارت جستجو از کاربر (اگر وارد شده باشد)
$search_term = isset($_GET['search']) ? $_GET['search'] : '';

// محاسبه صفحه فعلی
$current_page = isset($_GET['page']) ? (int)$_GET['page'] : 1;

// محاسبه OFFSET
$offset = ($current_page - 1) * $products_per_page;

// ایجاد کوئری برای جستجو
$query = "SELECT * FROM tbl_product WHERE name LIKE :search_term ORDER BY id DESC LIMIT :limit OFFSET :offset";
$stmt = $conn->prepare($query);
$stmt->bindValue(':search_term', '%' . $search_term . '%', PDO::PARAM_STR);
$stmt->bindParam(':limit', $products_per_page, PDO::PARAM_INT);
$stmt->bindParam(':offset', $offset, PDO::PARAM_INT);
$stmt->execute();
$products = $stmt->fetchAll(PDO::FETCH_ASSOC);

// برای هر محصول، تصاویر گالری آن را دریافت می‌کنیم
foreach ($products as $index => $product) {
    $product_id = $product['id'];
    $stmt = $conn->prepare("SELECT * FROM product_images WHERE product_id = :product_id");
    $stmt->bindParam(':product_id', $product_id);
    $stmt->execute();
    $images = $stmt->fetchAll(PDO::FETCH_ASSOC);
    $products[$index]['images'] = $images;
}

// محاسبه تعداد کل محصولات برای جستجو
$stmt = $conn->prepare("SELECT COUNT(*) FROM tbl_product WHERE name LIKE :search_term");
$stmt->bindValue(':search_term', '%' . $search_term . '%', PDO::PARAM_STR);
$stmt->execute();
$total_products = $stmt->fetchColumn();

// محاسبه تعداد صفحات
$total_pages = ceil($total_products / $products_per_page);
?>

<!DOCTYPE html>
<html lang="fa" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>مدیریت محصولات</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.rtl.min.css" rel="stylesheet">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
</head>
<body class="bg-light">
    <div class="container mt-5">
        <h3>مدیریت محصولات</h3>

        <!-- فرم جستجو -->
        <form method="get" class="mb-3">
            <div class="input-group">
                <input type="text" class="form-control" name="search" value="<?= htmlspecialchars($search_term) ?>" placeholder="جستجو بر اساس نام محصول">
                <button class="btn btn-primary" type="submit">جستجو</button>
            </div>
        </form>

        <!-- جدول برای نمایش محصولات -->
        <table class="table table-striped table-bordered">
            <thead>
                <tr>
                    <th>نام محصول</th>
                    <th>توضیحات</th>
                    <th>تصویر اصلی</th>
                    <th>گالری تصاویر</th>
                    <th>عملیات</th> <!-- ستون جدید برای عملیات -->
                </tr>
            </thead>
            <tbody>
                <?php foreach ($products as $product): ?>
                    <tr>
                        <td><?= $product['name'] ?></td>
                        <td><?= $product['description'] ?></td>
                        <td>
                            <img src="<?= $product['image_url'] ?>" alt="<?= $product['name'] ?>" style="height: 100px; object-fit: cover;">
                        </td>
                        <td>
                            <div class="row">
                                <?php foreach ($product['images'] as $image): ?>
                                    <div class="col-4 mb-2">
                                        <img src="<?= $image['image_url'] ?>" class="img-fluid" alt="Product Image" style="height: 50px; object-fit: cover;">
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        </td>
                        <td>
                            <a href="edit_product.php?id=<?= $product['id'] ?>" class="btn btn-warning btn-sm">ویرایش</a>
                            <a href="delete_product.php?id=<?= $product['id'] ?>" class="btn btn-danger btn-sm" onclick="return confirm('آیا مطمئنید؟')">حذف</a>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>

        <!-- نمایش صفحه بندی -->
        <nav>
            <ul class="pagination justify-content-center">
                <?php if ($current_page > 1): ?>
                    <li class="page-item">
                        <a class="page-link" href="manage_products.php?page=1&search=<?= urlencode($search_term) ?>" aria-label="اولین صفحه">
                            <span aria-hidden="true">&laquo;&laquo;</span>
                        </a>
                    </li>
                    <li class="page-item">
                        <a class="page-link" href="manage_products.php?page=<?= $current_page - 1 ?>&search=<?= urlencode($search_term) ?>" aria-label="صفحه قبلی">
                            <span aria-hidden="true">&laquo;</span>
                        </a>
                    </li>
                <?php endif; ?>
                
                <?php for ($page = 1; $page <= $total_pages; $page++): ?>
                    <li class="page-item <?= ($page == $current_page) ? 'active' : '' ?>">
                        <a class="page-link" href="manage_products.php?page=<?= $page ?>&search=<?= urlencode($search_term) ?>"><?= $page ?></a>
                    </li>
                <?php endfor; ?>
                
                <?php if ($current_page < $total_pages): ?>
                    <li class="page-item">
                        <a class="page-link" href="manage_products.php?page=<?= $current_page + 1 ?>&search=<?= urlencode($search_term) ?>" aria-label="صفحه بعدی">
                            <span aria-hidden="true">&raquo;</span>
                        </a>
                    </li>
                    <li class="page-item">
                        <a class="page-link" href="manage_products.php?page=<?= $total_pages ?>&search=<?= urlencode($search_term) ?>" aria-label="آخرین صفحه">
                            <span aria-hidden="true">&raquo;&raquo;</span>
                        </a>
                    </li>
                <?php endif; ?>
            </ul>
        </nav>

    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
