<?php
require 'connect.php'; // فایل تنظیمات و اتصال به دیتابیس

$base_url = "https://www.android-pro.ir/shopp/add/web/"; // آدرس پایه برای تصاویر

// دریافت لیست اسلایدرها
$stmt = $conn->prepare("SELECT s.id, s.idP, s.image_slider, p.name AS product_name 
                       FROM tbl_slider s 
                       LEFT JOIN tbl_product p ON s.idP = p.id");
$stmt->execute();
$sliders = $stmt->fetchAll(PDO::FETCH_ASSOC);

// دریافت لیست محصولات برای فرم افزودن
$stmt = $conn->prepare("SELECT id, name FROM tbl_product");
$stmt->execute();
$products = $stmt->fetchAll(PDO::FETCH_ASSOC);

// افزودن اسلاید جدید
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $product_id = $_POST['product_id'];

    if (!empty($_FILES['image']['name'])) {
        $image_name = time() . '_' . $_FILES['image']['name'];
        move_uploaded_file($_FILES['image']['tmp_name'], "uploads/$image_name");
        $image_url = $base_url . "uploads/" . $image_name;
    } else {
        $image_url = $base_url . $_POST['image_url'];
    }

    $stmt = $conn->prepare("INSERT INTO tbl_slider (idP, image_slider) VALUES (:idP, :image)");
    $stmt->bindParam(":idP", $product_id, PDO::PARAM_INT);
    $stmt->bindParam(":image", $image_url, PDO::PARAM_STR);
    $stmt->execute();

    header("Location: manage_slider.php");
    exit();
}

// حذف اسلاید
if (isset($_GET['delete'])) {
    $id = $_GET['delete'];
    $stmt = $conn->prepare("DELETE FROM tbl_slider WHERE id = :id");
    $stmt->bindParam(":id", $id, PDO::PARAM_INT);
    $stmt->execute();
    header("Location: manage_slider.php");
    exit();
}
?>

<!DOCTYPE html>
<html lang="fa">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>مدیریت اسلایدر</title>
    
    <!-- لینک بوت‌استرپ -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    
    <!-- فونت فارسی -->
    <link href="https://cdn.jsdelivr.net/gh/rastikerdar/iransans@5.0/webfonts/fonts.css" rel="stylesheet">
    
    <style>
        body {
            font-family: 'IRANSans', sans-serif;
            background-color: #f8f9fa;
            direction: rtl;
            text-align: right;
        }
        .container {
            max-width: 900px;
            margin-top: 20px;
        }
        .table img {
            width: 80px;
            height: auto;
            border-radius: 5px;
        }
        .btn-danger {
            font-size: 14px;
        }
    </style>
</head>
<body>

<div class="container">
    <h2 class="text-center mb-4">مدیریت اسلایدر</h2>

    <div class="card shadow p-3 mb-4">
        <div class="card-body">
            <form method="POST" enctype="multipart/form-data">
                <div class="mb-3">
                    <label class="form-label">انتخاب محصول:</label>
                    <select name="product_id" class="form-select" required>
                        <?php foreach ($products as $row) { ?>
                            <option value="<?= $row['id'] ?>"><?= $row['id'] ?> - <?= $row['name'] ?></option>
                        <?php } ?>
                    </select>
                </div>
                
                <div class="mb-3">
                    <label class="form-label">آپلود تصویر:</label>
                    <input type="file" name="image" class="form-control">
                </div>

                <div class="mb-3">
                    <label class="form-label">یا لینک تصویر (بدون آدرس سایت):</label>
                    <input type="text" name="image_url" class="form-control">
                </div>

                <button type="submit" class="btn btn-success w-100">افزودن اسلاید</button>
            </form>
        </div>
    </div>

    <h3 class="text-center mb-3">لیست اسلایدرها</h3>
    <table class="table table-striped table-bordered text-center">
        <thead class="table-dark">
            <tr>
                <th>تصویر</th>
                <th>شناسه محصول</th>
                <th>نام محصول</th>
                <th>عملیات</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($sliders as $row) { ?>
                <tr>
                    <td><img src="<?= $row['image_slider'] ?>" alt="اسلایدر"></td>
                    <td><?= $row['idP'] ?></td>
                    <td><?= $row['product_name'] ?></td>
                    <td>
                        <a href="manage_slider.php?delete=<?= $row['id'] ?>" class="btn btn-danger" onclick="return confirm('آیا از حذف این اسلاید مطمئن هستید؟')">حذف</a>
                    </td>
                </tr>
            <?php } ?>
        </tbody>
    </table>
</div>

<!-- اسکریپت بوت‌استرپ -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

</body>
</html>
